TabContainer BIDI DOH Test

# Bidi TabContainer tests

## TabContainer with RTL text direction and changed tabs

Title of this LTR pane has been changed
Title of this pane with no text direction specified (inherited) has been changed
Explicit LTR text direction of content pane
Inherited RTL text direction of content pane tab

## TabContainer with RTL text direction

Explicit LTR text direction of content pane
Inherited RTL text direction of content pane tab
Explicit 'auto' text direction of content pane
Explicit RTL text direction of content pane
Errors: ?
Failures: ?